==> ara_cli-0.1.4.47.tar.gz: ara_cli-0.1.4.47/ara_cli/update_config_prompt.py <==
import os

def read_file(filepath):
    """Read and return the content of a file."""
    with open(filepath, 'r') as file:
        return file.read()

def write_file(filepath, content):
    """Write content to a file."""
    with open(filepath, 'w') as file:
        file.write(content)

def find_checked_items(content):
    """
    Find all checked items ([x]) in the content and return a list of their sections and items.
    """
    sections = []
    checked_items = []
    lines = content.split('\n')
    
    for line in lines:
        if line.startswith('#'):
            sections = [line]  # Reset sections for new top-level header
        elif line.startswith('##'):
            if len(sections) == 1:
                sections.append(line)  # Add sub-section under top-level header
        if '[x]' in line:
            item = ''.join(sections) + line.strip()
            checked_items.append(item)
    
    return checked_items

def update_items_in_file(content, checked_items):
    """
    Update items in the content based on the checked items found.
    """
    sections = []
    updated_lines = []
    lines = content.split('\n')
    for line in lines:
        if line.startswith('#'):
            sections = [line]  # Reset sections for new top-level header
        elif line.startswith('##'):
            if len(sections) == 1:
                sections.append(line)  # Add sub-section under top-level header
        section_path = ''.join(sections)
        if '[]' in line:
            for item in checked_items:
                if section_path in item and line.strip() in item.replace('[x]', '[]'):
                    line = line.replace('[]', '[x]')
                    print(f"Updated: {item}")
                    break
        updated_lines.append(line)
    
    return '\n'.join(updated_lines)

def update_config_prompt_files(input1, input2):
    """
    Update the prompt config files with the new chat.
    """
    content1 = read_file(input1)
    content2 = read_file(input2)
    
    checked_items = find_checked_items(content1)
    
    updated_content2 = update_items_in_file(content2, checked_items)
    
    write_file(input2, updated_content2)
    
    # Overwrite input1 with input2 and delete input2
    os.replace(input2, input1)

    # Ensure the tmp file exists before attempting to delete
    if os.path.exists(input2):
        os.remove(input2)
        print(f"Debug: Deleted temporary file {input2}")
    else:
        print(f"Debug: Temporary file {input2} does not exist")
    print("Update process completed.")

==> ara_cli-0.1.4.51.tar.gz: ara_cli-0.1.4.51/ara_cli/update_config_prompt.py <==
import os

def read_file(filepath):
    """Read and return the content of a file."""
    with open(filepath, 'r') as file:
        return file.read()

def write_file(filepath, content):
    """Write content to a file."""
    with open(filepath, 'w') as file:
        file.write(content)

def find_checked_items(content):
    """
    Find all checked items ([x]) in the content and return a list of their sections and items.
    """
    sections = []
    checked_items = []
    lines = content.split('\n')
    
    for line in lines:
        if line.startswith('#'):
            header_level = line.count('#')
            sections = sections[:header_level-1]  # Trim sections to the current header level
            sections.append(line)
        if '[x]' in line:
            item = ''.join(sections) + line.strip()
            checked_items.append(item)

    return checked_items


def update_items_in_file(content, checked_items):
    """
    Update items in the content based on the checked items found.
    """
    sections = []
    updated_lines = []
    lines = content.split('\n')

    for line in lines:
        if line.startswith('#'):
            header_level = line.count('#')
            sections = sections[:header_level-1]  # Trim sections to the current header level
            sections.append(line)
        section_path = ''.join(sections)
        if '[]' in line:
            for item in checked_items:
                if section_path in item and line.strip() in item.replace('[x]', '[]'):
                    line = line.replace('[]', '[x]')
                    print(f"Updated: {item}")
                    break
        updated_lines.append(line)

    return '\n'.join(updated_lines)

def update_config_prompt_files(input1, input2):
    """
    Update the prompt config files with the new chat.
    """
    content1 = read_file(input1)
    content2 = read_file(input2)
    
    checked_items = find_checked_items(content1)
    
    updated_content2 = update_items_in_file(content2, checked_items)
    
    write_file(input2, updated_content2)
    
    # Overwrite input1 with input2 and delete input2
    os.replace(input2, input1)

    # Ensure the tmp file exists before attempting to delete
    if os.path.exists(input2):
        os.remove(input2)
        print(f"Debug: Deleted temporary file {input2}")
    else:
        print(f"Debug: Temporary file {input2} does not exist")
    print("Update process completed.")
